@@ -1,22 +1,22 @@
 /*
-* Copyright (C) 2011~2017 by CSSlayer
-* wengxt@gmail.com
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions
-* are met:
-*
-* 1. Redistributions of source code must retain the above Copyright
-*    notice, this list of conditions and the following disclaimer.
-*
-* 2. Redistributions in binary form must reproduce the above Copyright
-*    notice, this list of conditions and the following disclaimer in the
-*    documentation and/or other materials provided with the distribution.
-*
-* 3. Neither the name of the authors nor the names of its contributors
-*    may be used to endorse or promote products derived from this
-*    software without specific prior written permission.
-*/
+ * Copyright (C) 2011~2017 by CSSlayer
+ * wengxt@gmail.com
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above Copyright
+ *    notice, this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above Copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * 3. Neither the name of the authors nor the names of its contributors
+ *    may be used to endorse or promote products derived from this
+ *    software without specific prior written permission.
+ */
 
 #include "fcitxinputcontextproxy.h"
 #include "fcitxwatcher.h"
@@ -117,8 +117,8 @@ void FcitxInputContextProxy::createInputContext() {
     QFileInfo info(QCoreApplication::applicationFilePath());
     if (service == "org.freedesktop.portal.Fcitx") {
         m_portal = true;
-        m_im1proxy = new org::fcitx::Fcitx::InputMethod1(owner, "/org/freedesktop/portal/inputmethod",
-                                                         connection, this);
+        m_im1proxy = new org::fcitx::Fcitx::InputMethod1(
+            owner, "/org/freedesktop/portal/inputmethod", connection, this);
         FcitxInputContextArgumentList list;
         FcitxInputContextArgument arg;
         arg.setName("program");
@@ -188,8 +188,9 @@ void FcitxInputContextProxy::createInputContextFinished() {
                 SLOT(forwardKeyWrapper(uint, uint, int)));
         connect(m_icproxy,
                 SIGNAL(UpdateFormattedPreedit(FcitxFormattedPreeditList, int)),
-                this, SLOT(updateFormattedPreeditWrapper(
-                          FcitxFormattedPreeditList, int)));
+                this,
+                SLOT(updateFormattedPreeditWrapper(FcitxFormattedPreeditList,
+                                                   int)));
     }
 
     delete m_createInputContextWatcher;
