@@ -1,28 +1,28 @@
 /*
-* Copyright (C) 2017~2017 by CSSlayer
-* wengxt@gmail.com
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions
-* are met:
-*
-* 1. Redistributions of source code must retain the above Copyright
-*    notice, this list of conditions and the following disclaimer.
-*
-* 2. Redistributions in binary form must reproduce the above Copyright
-*    notice, this list of conditions and the following disclaimer in the
-*    documentation and/or other materials provided with the distribution.
-*
-* 3. Neither the name of the authors nor the names of its contributors
-*    may be used to endorse or promote products derived from this
-*    software without specific prior written permission.
-*/
+ * Copyright (C) 2017~2017 by CSSlayer
+ * wengxt@gmail.com
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above Copyright
+ *    notice, this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above Copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * 3. Neither the name of the authors nor the names of its contributors
+ *    may be used to endorse or promote products derived from this
+ *    software without specific prior written permission.
+ */
 
 #ifndef FCITXWATCHER_H_
 #define FCITXWATCHER_H_
 
-#include <QObject>
 #include <QDBusConnection>
+#include <QObject>
 
 class QDBusConnection;
 class QFileSystemWatcher;
@@ -34,7 +34,8 @@ class QDBusServiceWatcher;
 class FcitxWatcher : public QObject {
     Q_OBJECT
 public:
-    explicit FcitxWatcher(QDBusConnection sessionBus, QObject *parent = nullptr);
+    explicit FcitxWatcher(QDBusConnection sessionBus,
+                          QObject *parent = nullptr);
     ~FcitxWatcher();
     void watch();
     void unwatch();
